@@ -1,5 +1,6 @@
 import json
 from pathlib import Path
+from functools import partial
 
 import numpy as np
 
@@ -141,7 +142,7 @@ _config_cache = {}
 
 
 async def execute(
-    inputs, server_url=None, model_name=None, cache_config=True, **kwargs
+    inputs=None, server_url=None, model_name=None, cache_config=True, **kwargs
 ):
     """
     Function for execute the model by passing a list of input tensors and using cached config
@@ -157,6 +158,41 @@ async def execute(
     return await execute_model(inputs, config=config, **kwargs)
 
 
+class SequenceExcutor:
+    """Execute a sequence by managing the sequence_start and sequence_end automatically"""
+
+    def __init__(self, auto_end=False, **kwargs) -> None:
+        self.kwargs = kwargs
+        if "sequence_id" not in kwargs:
+            raise Exception("Please provide sequence_id")
+        self._seq_start = True
+        self._last_args = None
+        self._auto_end = auto_end
+
+    async def execute(self, *args, **kwargs):
+        if "sequence_start" in kwargs:
+            raise Exception(
+                "sequence_start are not allowed keywords in sequence executor"
+            )
+        kwargs.update(self.kwargs)
+        if self._auto_end:
+            self._last_args = (args, kwargs)
+        if self._seq_start:
+            self._seq_start = False
+            return await execute(*args, sequence_start=True, **kwargs)
+        else:
+            return await execute(*args, sequence_start=False, **kwargs)
+
+    async def __aenter__(self):
+        self._seq_start = True
+        return self
+
+    async def __aexit__(self, exc_type, exc_val, exc_tb):
+        if self._auto_end and self._last_args:
+            (args, kwargs) = self._last_args
+            await execute(*args, sequence_start=False, sequence_end=True, **kwargs)
+
+
 # read version information from file
 VERSION_INFO = json.loads(
     (Path(__file__).parent / "VERSION").read_text(encoding="utf-8").strip()
